** Ghana DHS analysis for MVP project. 
**All files with "GH" prefix pertain to files directly downloaded from DHS surveys of Ghana in 2003 and 2008.
**These files can be downloaded here: http://www.measuredhs.com/accesssurveys/search/show_datasets.cfm?Surv_Id=301&Ctry_id=14&SrvyTp=available&flag=0
** and here: http://www.measuredhs.com/accesssurveys/search/show_datasets.cfm?Surv_Id=235&Ctry_id=14&SrvyTp=available&flag=0
** There are no modifications required to the DHS data to run this do-file. 

version 11
clear all
set matsize 800
set more off

cd "H:\CGD work\Migration\Millenium Villages\For website"

********************
********************
**                **
**   GHANA 2008   **
**                **
********************
********************

preserve
use "GHPR5HFL.DTA"

* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6

* Creating coverage variables. The Bonsaaso, Ghana MV cluster is located in the Ashanti region. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 6 & hv025 == 2)

* Set the survey design
capture svyset, clear
svyset hv001 [pweight=weight], strata(hv022) 

* Creating a subset of one observation per household. 
sort hhid
by hhid: gen hhmem = 1 if _n ==1
replace hhmem = 0 if hhmem ==.

***************
*  Schooling  *
***************

gen attended_primary = hv122==1 if (hv105>5 & hv103==1)
gen age = hv105
gen primaryage = (age >= 6 & age <= 11) if hv103==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): total attended_primary 
	matrix aux_prim_students_`x'08 = e(b)
	sca prim_students_`x'08=aux_prim_students_`x'08[1,1] 
svy, subpop (if `x'): total primaryage
	matrix aux_prim_age_kids_`x'08 = e(b)
	sca prim_age_kids_`x'08=aux_prim_age_kids_`x'08[1,1]
sca prim_result_gen_`x'08 = prim_students_`x'08/prim_age_kids_`x'08	
dis prim_result_gen_`x'08
svy, subpop (if `x'): ratio attended_primary / primaryage
}
* Agrees with Ghana DHS 2008 Final Report Table 2.5 page 19

* However, we must now include children below age of 6 in numerator for comparison with MV report.

drop attended_primary
gen attended_primary = hv122==1 if hv103==1

/* Use bootstrap command to produce standard errors. Bootstrap does not allow pweights => transform the
variables first. Check against the classical way of calculating the GPA ratio */

gen prage=weight*primaryage if attended_primary!=.
gen attprimary=weight*attended_primary

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): ratio attended_primary / primaryage
*bootstrap, rep(1000) strata(hv022) cluster(hv001): ratio attprimary / prage if `x'
	matrix aux_gpa_`x'08=e(b)
	sca prim_result_`x'08=aux_gpa_`x'08[1,1]
	matrix aux2_gpa_`x'08=e(V)
	sca var=aux2_gpa_`x'08[1,1]
	sca prim_sd_`x'08=sqrt(var)
dis prim_result_`x'08
dis prim_sd_`x'08
}

*************
*  Bednets  *
*************

rename hc1 age_months
gen itn = hml12 == 1
replace itn=. if itn == 9

foreach x of varlist all rural mvregion {
svy, subpop(if (age_months < 60 & `x')): proportion itn
	matrix aux_itn_`x'08=e(b)
	sca itn_result_`x'08=aux_itn_`x'08[1,2]
	matrix aux2_itn_`x'08=e(V)
	sca var=aux2_itn_`x'08[2,2]
	sca itn_sd_`x'08=sqrt(var)
sca itn_result_`x'08=itn_result_`x'08
sca itn_sd_`x'08=itn_sd_`x'08
dis itn_result_`x'08
dis itn_sd_`x'08
}

*Our result of 28.2 matches the final report in table 12.2 on p.224.

*******************
*  Mobile phones  *
*******************

gen mobile = hv243a == 1
replace mobile = . if hv243a == 9
by hhid: egen hasmobile = max(mobile)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & hhmem == 1 ): proportion mobile
	matrix aux_phone_`x'08=e(b)
	sca phone_result_`x'08=aux_phone_`x'08[1,2]
	matrix aux2_phone_`x'08=e(V)
	sca var=aux2_phone_`x'08[2,2]
	sca phone_sd_`x'08=sqrt(var)
dis phone_result_`x'08
dis phone_sd_`x'08
}
* Result of 57.0 matches the final report in table 2.10 on p.27.

***********
*  Water  *
***********

* First check against data in Kenya 2008 DHS Final Report
* Improved source of drinking water. 

gen improved_drinking = 0
replace improved_drinking = 1 if (hv201 >= 10 & hv201 <= 31) | hv201 == 41 | hv201 == 51
by hhid: egen hhimproved_drinking = max(improved_drinking)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & hhmem == 1): proportion hhimproved_drinking 
	matrix aux_water_`x'08=e(b)
	sca water_result_`x'08=aux_water_`x'08[1,2]
	matrix aux2_water_`x'08=e(V)
	sca var=aux2_water_`x'08[2,2]
	sca water_sd_`x'08=sqrt(var)
dis water_result_`x'08
dis water_sd_`x'08
}

* There is only 1 category for "spring" in 2003 whereas there are two categories in 2008:
*protected spring (improved) and unprotected spring (not improved).
*We need to save "relative" and "absolute" percentage of protected spring for further analysis in 2003 */

* 1. "Relative" proportion of protected springs out of all springs (protected and unprotected)

gen protspring=1 if hv201==41
replace protspring=0 if hv201==42
by hhid: egen hh_protspring = max(protspring)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hh_protspring 
	matrix aux_spring_`x'08=e(b)
	sca spring_relative_`x'08=aux_spring_`x'08[1,2]
dis spring_relative_`x'08
}

* 2. "Absolute" proportion of protected springs out of all types of water supply types.

* CHECK whether protected spring is in the 7th row of svy proportion output and if not change the command: sca spring_absolute_`x'08=aux_spring2_`x'08[1,7]

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hv201 
	matrix aux_spring2_`x'08=e(b)
	sca spring_absolute_`x'08=aux_spring2_`x'08[1,7]
	matrix aux2_spring2_`x'08=e(V)
	sca var = aux2_spring2_`x'08[7,7]
	sca spring_absolutesd_`x'08= sqrt(var)
dis spring_absolute_`x'08
}
****************
*  Sanitation  *
****************

* First check against data in Kenya 2008 DHS Final Report
* Note that Final Report p. 22 defines any shared facility as non-improved
gen improved_sanitation = 0
replace improved_sanitation = 1 if ((hv205 >= 11 & hv205<= 13) | hv205 == 21| hv205 == 22) & hv225 == 0
by hhid: egen hhimproved_sanitation = max(improved_sanitation)

svy, subpop ( if hhmem == 1): proportion hhimproved_sanitation
svy, subpop ( if rural==1 & hhmem == 1): proportion hhimproved_sanitation

drop improved_sanitation
drop hhimproved_sanitation

* BUT the MV report does *not* define 'shared' as 'unimproved'
*Furthermore, ALL flush toilets shall be defined as improved
*So the calculation must be redone for comparability: */
 
gen improved_sanitation = 0
replace improved_sanitation = 1 if (hv205 >= 11 & hv205<= 22)
by hhid: egen hhimproved_sanitation = max(improved_sanitation)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hhimproved_sanitation 
	matrix aux_sani_`x'08=e(b)
	sca sani_result_`x'08=aux_sani_`x'08[1,2]
	matrix aux2_sani_`x'08=e(V)
	sca var=aux2_sani_`x'08[2,2]
	sca sani_sd_`x'08=sqrt(var)
dis sani_result_`x'08
dis sani_sd_`x'08
}

* There is only 1 category for "traditional pit latrine" in 2003 whereas there are two categories in 2008:
*with slab (improved) and without slab (not improved).
*We need to save "relative" and "absolute" percentage of latrine with slab for further analysis in 2003 */

* 1. "Relative" proportion of latrine with slab out of all latrines (with and without slab)

gen slabpit=1 if hv205==22
replace slabpit=0 if hv205==23
by hhid: egen hh_slabpit = max(slabpit)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hh_slabpit 
	matrix aux_pit_`x'08=e(b)
	sca slab_relative_`x'08=aux_pit_`x'08[1,2]
dis slab_relative_`x'08
}

* 2. "Absolute" proportion of latrines with slab out of all types of sanitation facilities.

* CHECK whether latrine with slab is in the 7th row of svy proportion output and if not change the command: sca slab_absolute_`x'08=aux_pit2_`x'08[1,7]

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1): proportion hv205 
	matrix aux_pit2_`x'08=e(b)
	sca slab_absolute_`x'08=aux_pit2_`x'08[1,7]
	matrix aux2_pit2_`x'08=e(V)
	sca var = aux2_pit2_`x'08[7,7]
	sca slab_absolutesd_`x'08= sqrt(var)
dis slab_absolute_`x'08
}

**************
*  Stunting  *
**************

*** Checking for comparison to Final Report
gen stunted=1 if (hc70<-200 & hv103==1) 
replace stunted=0 if (hc70>=-200 & hc70<601 & hv103==1)

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion stunted 
	matrix aux_stunted_gen_`x'08=e(b)
	sca stunted_gen_result_`x'08=aux_stunted_gen_`x'08[1,2]
	matrix aux2_stunted_gen_`x'08=e(V)
	sca var=aux2_stunted_gen_`x'08[2,2]
	sca stunted_gen_sd_`x'08=sqrt(var)
}
* Agrees with Final Report table 11.2 p. 145

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & age_months<24): proportion stunted 
	matrix aux_stunted_`x'08=e(b)
	sca stunted_result_`x'08=aux_stunted_`x'08[1,2]
	matrix aux2_stunted_`x'08=e(V)
	sca var=aux2_stunted_`x'08[2,2]
	sca stunted_sd_`x'08=sqrt(var)
dis stunted_result_`x'08
dis stunted_sd_`x'08
}

restore

*** Switching to children's recode

preserve
use "GHKR5HFL.dta"

gen weight = v005/1e6

* Creating coverage variables. The Bonsaaso, Ghana MV cluster is located in the Ashanti region. 
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 6 & v025 == 2)
svyset v001 [pweight=weight], strata(v022)

*************************
*  Measles vaccination  *
*************************
gen measles = (h9 == 1 | h9 == 2)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & b8==1): proportion measles
	matrix aux_measles_`x'08=e(b)
	sca measles_result_`x'08=aux_measles_`x'08[1,2]
	matrix aux2_measles_`x'08=e(V)
	sca var=aux2_measles_`x'08[2,2]
	sca measles_sd_`x'08=sqrt(var)
dis measles_result_`x'08
dis measles_sd_`x'08
}

* Agrees with Final Report table 10.2 p. 165, but not with the value for percentage of children vaccinated before age of 12 months. 

**********************
*  Birth attendance  *
**********************

* Applies to most recent birth (see Final Report p. 405)

gen skilled = (m3a == 1 | m3b == 1 | m3c == 1 | m3d == 1)
replace skilled = 0 if skilled != 1 & m3a != . & m3b != . & m3c != . & m3d != .
summ skilled [w=weight]
* Agrees  exactly with with Final Report table 9.6 p. 156

* In MV report, traditional health worker is not defined as a skilled attendant and we only calculate for births under two years old. 
replace skilled = 0 if m3d == 1

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & b8<2): proportion skilled
	matrix aux_skilled_`x'08=e(b)
	sca skilled_result_`x'08=aux_skilled_`x'08[1,2]
	matrix aux2_skilled_`x'08=e(V)
	sca var=aux2_skilled_`x'08[2,2]
	sca skilled_sd_`x'08=sqrt(var)
dis skilled_result_`x'08
dis skilled_sd_`x'08
}
restore

***************
* HIV testing *
***************

***2008
*** Females
preserve
use v001 v005 v024 v022 v025 v826 v828 using "GHIR5HFL.dta"
gen weight = v005/1e6
gen rural = v025 == 2
gen mvregion = (v024 == 6 & v025 == 2)
gen all = 1
svyset v001 [pweight=weight], strata(v022) 

gen hiv_tested = v826 == 1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion hiv_tested 
	matrix aux_hiv_F_`x'08=e(b)
	sca hiv_F_result_`x'08=aux_hiv_F_`x'08[1,2]
	matrix aux2_hiv_F_`x'08=e(V)
	sca var=aux2_hiv_F_`x'08[2,2]
	sca hiv_F_sd_`x'08=sqrt(var)
	sca hiv_F_obs_`x'08 = e(N)
dis hiv_F_result_`x'08
dis hiv_F_sd_`x'08
}
* Agrees with final report in table 13.10.1 on p.256 (6.8 in both cases).
restore

*** Males
preserve
use mv001 mv005 mv012 mv024 mv022 mv025 mv826 mv828 using "GHMR5HFL.dta"
gen weight = mv005/1e6
gen rural = mv025 == 2
gen mvregion = (mv024 == 6 & mv025 == 2)
gen all = 1
gen hiv_tested = mv826 == 1
svyset mv001 [pweight=weight], strata(mv022)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & mv012<50): proportion hiv_tested				//male up to 49 years
	matrix aux_hiv_M_`x'08=e(b)
	sca hiv_M_result_`x'08=aux_hiv_M_`x'08[1,2]
	matrix aux2_hiv_M_`x'08=e(V)
	sca var=aux2_hiv_M_`x'08[2,2]
	sca hiv_M_sd_`x'08=sqrt(var)
	sca hiv_M_obs_`x'08 = e(N)
dis hiv_M_result_`x'08
dis hiv_M_sd_`x'08
}
* Agrees with final report in table 13.10.2 on p.257 (4.1 in both cases).
restore


preserve
use "GHPR5HFL.dta"
* Creating coverage variables. Sauri is in the Nyanza province, Kenya. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 6 & hv025 == 2)
* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6
* Set the survey design
capture svyset, clear
svyset hv001 [pweight=weight], strata(hv022) 

* Weighted average of F and M indicator value
gen female=hv104==2		//dummy for female

foreach x of varlist all rural mvregion {
summ female [w=weight] if hv105<50 & hv105>14 & `x'	//population share of females (population aged 15-49)
	sca pop_share_F_`x'08 = r(mean)
	sca pop_share_M_`x'08 = 1 - pop_share_F_`x'08
sca hiv_result_`x'08 = pop_share_M_`x'08*hiv_M_result_`x'08 + pop_share_F_`x'08*hiv_F_result_`x'08
dis hiv_result_`x'08
sca hiv_sd_`x'08 = sqrt(((pop_share_F_`x'08 * hiv_F_sd_`x'08)^2) + ((1 - pop_share_F_`x'08) * hiv_M_sd_`x'08 )^2)
}
restore

********************
********************
**                **
**   GHANA 2003   **
**                **
********************
********************

preserve
use "GHPR4BFL.DTA"

*************************
*   Prepare variables   *
*************************

* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6

* Creating coverage variables. The Bonsaaso, Ghana MV cluster is located in the Ashanti region. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 6 & hv025 == 2)

* Set the survey design
capture svyset, clear
svyset hv001 [pweight=weight], strata(hv022) 

* Creating a subset of one observation per household. 
sort hhid
by hhid: gen hhmem = 1 if _n ==1
replace hhmem = 0 if hhmem ==.

***************
*  Schooling  *
***************

*** Checking for comparison to Final Report
gen attended_primary = hv122==1 if (hv105>5 & hv103==1)
gen age = hv105
gen primaryage = (age >= 6 & age <= 11) if hv103==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): total attended_primary 
	matrix aux_prim_students_`x'03 = e(b)
	sca prim_students_`x'03=aux_prim_students_`x'03[1,1] 
svy, subpop (if `x'): total primaryage
	matrix aux_prim_age_kids_`x'03 = e(b)
	sca prim_age_kids_`x'03=aux_prim_age_kids_`x'03[1,1]
sca prim_result_gen_`x'03 = prim_students_`x'03/prim_age_kids_`x'03	
dis prim_result_gen_`x'03
svy, subpop (if `x'): ratio attended_primary / primaryage
}

* NOTE: Slightly different numbers: Final Report 2003 p. 18 says 95.4. Our result 94.9.
* Rural area: Report 89.6, Our result 89.1. 

* Re-do for comparison to MV report.

drop attended_primary
gen attended_primary = hv122==1 if hv103==1

/* Use bootstrap command to produce standard errors. Bootstrap does not allow pweights => transform the
variables first. Check against the clasissical way of calculating the GPA ratio */

gen prage=weight*primaryage if attended_primary!=.
gen attprimary=weight*attended_primary

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): ratio attended_primary / primaryage
*bootstrap, rep(1000) strata(hv022) cluster(hv001): ratio attprimary / prage if `x'
	matrix aux_gpa_`x'03=e(b)
	sca prim_result_`x'03=aux_gpa_`x'03[1,1]
	matrix aux2_gpa_`x'03=e(V)
	sca var=aux2_gpa_`x'03[1,1]
	sca prim_sd_`x'03=sqrt(var)
dis prim_result_`x'03
dis prim_sd_`x'03
}

*************
*  Bednets  *
*************

gen age_months = hc1
gen itn = hml12 == 1

foreach x of varlist all rural mvregion {
svy, subpop (if age_months<60 & `x'): proportion itn
	matrix aux_itn_`x'03=e(b)
	sca itn_result_`x'03=aux_itn_`x'03[1,2]
	matrix aux2_itn_`x'03=e(V)
	sca var=aux2_itn_`x'03[2,2]
	sca itn_sd_`x'03=sqrt(var)
sca itn_result_`x'03=itn_result_`x'03
sca itn_sd_`x'03=itn_sd_`x'03
dis itn_result_`x'03
dis itn_sd_`x'03
}
* Final Report 2003 p. 197 says 3.5, our results say 3.8

*******************
*  Mobile phones  *
*******************

* Ghana 2003 survey only asks about any phone, not specifically mobile phones.
gen anyphone = hv221 == 1
replace anyphone = . if hv221 == 9
by hhid: egen hasphone = max(anyphone)

foreach x of varlist all rural mvregion {
svy, subpop (if hhmem == 1 & `x'): proportion hasphone
	matrix aux_phone_`x'03=e(b)
	sca phone_result_`x'03=aux_phone_`x'03[1,2]
	matrix aux2_phone_`x'03=e(V)
	sca var=aux2_phone_`x'03[2,2]
	sca phone_sd_`x'03=sqrt(var)
sca phone_result_`x'03=phone_result_`x'03
sca phone_sd_`x'03=phone_sd_`x'03
dis phone_result_`x'03
dis phone_sd_`x'03
}
* Final Report 2003 p. 22 says 6.9, our result matches.

**********
*  Water *
**********

* Final Report 2003 does not provide a statistic for improved water, so check calculation against 
* reported value of percent of households with "Piped into dwelling/yard/plot" as source of drinking water. */

gen piped_water = (hv201 == 11| hv201 == 12)
by hhid: egen hhpiped_water = max(piped_water)

svy, subpop ( if hhmem == 1): proportion hhpiped_water
svy, subpop ( if rural==1 & hhmem == 1): proportion hhpiped_water

* There is only 1 category for "spring" in 2003 whereas there are two categories in 2008:
*protected spring (improved) and unprotected spring (not improved).
*"Relative" and "absolute" percentage of protected spring was saved in 2008 and will be used for further analysis */

gen improved_water = 0
replace improved_water = 1 if (hv201 >= 10 & hv201 <= 13) | (hv201 >= 30 & hv201 <= 33) | hv201 == 51 
by hhid: egen hhimproved_water = max(improved_water)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & hhmem == 1): proportion hhimproved_water  
	matrix aux_water_`x'03=e(b)
	sca water_result0_`x'03=aux_water_`x'03[1,2]
	matrix aux2_water_`x'03=e(V)
	sca var=aux2_water_`x'03[2,2]
	sca water_sd0_`x'03=sqrt(var)
dis water_result0_`x'03
dis water_sd0_`x'03
}

* 1. Approach: We assume that the "relative" proportion of protected springs out of all springs 
*(protected and unprotected) was the same in 2003 as in 2008

* CHECK whether spring is in the 8th row of svy proportion output and if not change the command: sca aux_water1_`x'03=aux_water_`x'03[1,8]

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1 ): proportion hv201
	matrix aux_water_`x'03=e(b)
	sca aux_water1_`x'03=aux_water_`x'03[1,10]		
	*percentage of springs in 2003
	dis aux_water1_`x'03
sca water_result1_`x'03 = water_result0_`x'03 + aux_water1_`x'03 * spring_relative_`x'08
	*result 2003 plus (% of springs in 2003 * proportion of protected springs out of all springs in 2008)
	sca water_sd1_`x'03=0
dis water_result1_`x'03
dis water_sd1_`x'03
}

* 2. Approach: We assume that the "absolute" proportion of protected springs out of all types of water 
*supply types was the same in 2003 as in 2008 */
foreach x of varlist all rural mvregion {
sca water_result2_`x'03 = water_result0_`x'03 + spring_absolute_`x'08	
	*result 2003 plus % of protected springs in 2008
	sca water_sd2_`x'03=sqrt(((water_sd0_`x'03)^2)+((spring_absolutesd_`x'08)^2))
dis water_result2_`x'03
dis water_sd2_`x'03
}

****************
*  Sanitation  *
****************

* Final Report 2003 does not provide a statistic for improved sanitation, so check calculation against 
*reported value of percent of households with "Flush toilet" as sanitation facility. */

gen flush_toilet = hv205 == 11
replace flush_toilet = . if hv205 == 99
by hhid: egen hhflush_toilet = max(flush_toilet)
svy, subpop ( if hhmem == 1): proportion hhflush_toilet
svy, subpop ( if rural==1 & hhmem == 1): proportion hhflush_toilet

* The MV report does *not* define 'shared' as 'unimproved'.
*There is only 1 category for "traditional pit latrine" in 2003 whereas there are two categories in 2008:
*with slab (improved) and without slab (not improved).
*"Relative" and "absolute" percentage of latrine with slab was saved in 2008 and will be used for further analysis */

gen improved_sanitation = 0
replace improved_sanitation = 1 if (hv205 == 11 | hv205== 22) 
by hhid: egen hhimproved_sanitation = max(improved_sanitation)

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1 ): proportion hhimproved_sanitation
	matrix aux_sani_`x'03=e(b)
	sca sani_result0_`x'03=aux_sani_`x'03[1,2]
	matrix aux2_sani_`x'03=e(V)
	sca var=aux2_sani_`x'03[2,2]
	sca sani_sd0_`x'03=sqrt(var)
dis sani_result0_`x'03
dis sani_sd0_`x'03
}

* 1. Approach: We assume that the "relative" proportion of latrines with slab out of all latrines 
*(with and without slab) was the same in 2003 as in 2008 */

* CHECK whether latrine is in the 2nd row of svy proportion output and if not change the command: sca aux_sani1_`x'03=aux_sani_`x'03[1,2]

foreach x of varlist all rural mvregion {
svy, subpop ( if `x' & hhmem == 1 ): proportion hv205
	matrix aux_sani_`x'03=e(b)
	sca aux_sani1_`x'03=aux_sani_`x'03[1,2]	
	*percentage of pit latrines in 2003	
	dis aux_sani1_`x'03
sca sani_result1_`x'03 = sani_result0_`x'03 + aux_sani1_`x'03 * slab_relative_`x'08
	*result 2003 plus (% of pit latrines in 2003 * proportion of latrines with slab out of pit latrines in 2008)
	sca sani_sd1_`x'03=0
dis sani_result1_`x'03
dis sani_sd1_`x'03
}

* 2. Approach: We assume that the "absolute" proportion of latrines with slab out of all types of sanitation 
* facilities was the same in 2003 as in 2008 */
foreach x of varlist all rural mvregion {
sca sani_result2_`x'03 = sani_result0_`x'03 + slab_absolute_`x'08	
	*result 2003 plus % of latrines with slab in 2008
	sca sani_sd2_`x'03= sqrt(((sani_sd0_`x'03)^2)+((slab_absolutesd_`x'08)^2))
dis sani_result2_`x'03
dis sani_sd2_`x'03
}

**************
*  Stunting  *
**************

sort hhid hvidx
keep  hhid hvidx hv001 hv005 hv022 hv024 hv025 hv103 hc1
rename hhid hwhhid
rename hvidx hwline
tempfile ghana_who
save "`ghana_who'", replace

use "GHHW4AFL.DTA", clear
sort hwhhid hwline
capture drop _merge
merge 1:1 hwhhid hwline using "`ghana_who'"
save "`ghana_who'", replace

* Creating coverage variables. The Bonsaaso, Ghana MV cluster is located in the Ashanti region. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 6 & hv025 == 2)
* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6
* Set the survey design
capture svyset, clear
svyset hv001 [pweight=weight], strata(hv022) 

gen age_months = hc1
gen stunted=1 if (hc70<-200 & hv103==1) 
replace stunted=0 if (hc70>=-200 & hc70<601 & hv103==1)

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & age_months<24): proportion stunted
matrix aux_stunted_`x'03=e(b)
	sca stunted_result_`x'03=aux_stunted_`x'03[1,2]
	matrix aux2_stunted_`x'03=e(V)
	sca var=aux2_stunted_`x'03[2,2]
	sca stunted_sd_`x'03=sqrt(var)
dis stunted_result_`x'03
dis stunted_sd_`x'03
}


restore

*** Children's Recode ***

preserve
use "GHKR4AFL.DTA"

gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 6 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022)

*************************
*  Measles vaccination  *
*************************

gen measles = (h9 == 1 | h9 == 2| h9 == 3)

foreach x of varlist all rural mvregion {
svy, subpop (if `x' & b8==1) : proportion measles
	matrix aux_measles_`x'03=e(b)
	sca measles_result_`x'03=aux_measles_`x'03[1,2]
	matrix aux2_measles_`x'03=e(V)
	sca var=aux2_measles_`x'03[2,2]
	sca measles_sd_`x'03=sqrt(var)
dis measles_result_`x'03
dis measles_sd_`x'03
}
* Final Report 2003 p. 152 says 83.2, which matches our results.
* Not the same as percentage of children vaccinated by age of 1. 

**********************
*  Birth attendance  *
**********************

* Applies to most recent birth

gen skilled = .
replace skilled = 1 if m3a == 1 | m3b == 1 | m3c == 1 
replace skilled = 0 if skilled != 1 

*** Checking for comparison to Final Report
foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion skilled
	matrix aux_skilled_gen_`x'03=e(b)
	sca skilled_gen_result_`x'03=aux_skilled_gen_`x'03[1,2]
	matrix aux2_skilled_gen_`x'03=e(V)
	sca var=aux2_skilled_gen_`x'03[2,2]
	sca skilled_gen_sd_`x'03=sqrt(var)
dis skilled_gen_result_`x'03
dis skilled_gen_sd_`x'03
}
* Final Report 2003 p. 150 says 47.1, our results match. 

*** Recalculating with children under 2 for comparability with MVP report
foreach x of varlist all rural mvregion {
svy, subpop (if `x' & b8<2): proportion skilled
	matrix aux_skilled_`x'03=e(b)
	sca skilled_result_`x'03=aux_skilled_`x'03[1,2]
	matrix aux2_skilled_`x'03=e(V)
	sca var=aux2_skilled_`x'03[2,2]
	sca skilled_sd_`x'03=sqrt(var)
dis skilled_result_`x'03
dis skilled_sd_`x'03
}
restore

*****************
*  HIV testing  *
*****************

* Females
preserve
use v025 v024 v005 v001 v826 v828 v022 using "GHIR4AFL.DTA", clear
gen all = 1
gen rural = v025 == 2
gen mvregion = (v024 == 6 & v025 == 2)
gen weight = v005/1e6
svyset v001 [pweight=weight], strata(v022) 
gen hivtest=0 
replace hivtest=1 if v826==1

foreach x of varlist all rural mvregion {
svy, subpop (if `x'): proportion hivtest
	matrix aux_hiv_F_`x'03=e(b)
	sca hiv_F_result_`x'03=aux_hiv_F_`x'03[1,2]
	matrix aux2_hiv_F_`x'03=e(V)
	sca var=aux2_hiv_F_`x'03[2,2]
	sca hiv_F_sd_`x'03=sqrt(var)
	sca hiv_F_obs_`x'03 = e(N)
dis hiv_F_result_`x'03
dis hiv_F_sd_`x'03
}
restore
* Agrees with Final Report table 12.10 p. 198

* Males
preserve
use mv025 mv024 mv005 mv001 mv826 mv828 mv012 mv022 using "GHMR4AFL.DTA", clear
gen all = 1
gen rural = mv025 == 2
gen mvregion = (mv024 == 6 & mv025 == 2)
gen weight = mv005/1e6
svyset mv001 [pweight=weight], strata(mv022) 
gen hivtest=0 
replace hivtest=1 if mv826==1

foreach x of varlist all rural mvregion {
svy, subpop (if (`x' & mv012<50)) : proportion hivtest				//male up to 49 years
	matrix aux_hiv_M_`x'03=e(b)
	sca hiv_M_result_`x'03=aux_hiv_M_`x'03[1,2]
	matrix aux2_hiv_M_`x'03=e(V)
	sca var=aux2_hiv_M_`x'03[2,2]
	sca hiv_M_sd_`x'03=sqrt(var)
	sca hiv_M_obs_`x'03 = e(N)
dis hiv_M_result_`x'03
dis hiv_M_sd_`x'03
}
restore
* Agrees with Final Report table 12.10 p. 198

preserve
use "GHPR4BFL.dta"
* Creating coverage variables. Sauri is in the Nyanza province, Kenya. 
gen all = 1
gen rural = hv025 == 2
gen mvregion = (hv024 == 6 & hv025 == 2)
* DHS weights must be divided by 1,000,000 according to http://www.measuredhs.com/help/Datasets/sampling_weights.htm
gen weight = hv005/1e6
* Set the survey design
capture svyset, clear
svyset hv001 [pweight=weight], strata(hv022) 

* Weighted average of F and M indicator value
gen female=hv104==2		//dummy for female

foreach x of varlist all rural mvregion {
summ female [w=weight] if hv105<50 & hv105>14 & `x'		//population share of females (population aged 15-49)
	sca pop_share_F_`x'03 = r(mean)
	sca pop_share_M_`x'03 = 1 - pop_share_F_`x'03
sca hiv_result_`x'03 = pop_share_M_`x'03*hiv_M_result_`x'03 + pop_share_F_`x'03*hiv_F_result_`x'03
dis hiv_result_`x'03
sca hiv_sd_`x'03 = sqrt(((pop_share_F_`x'03 * hiv_F_sd_`x'03)^2) + (((1 - pop_share_F_`x'03) * hiv_M_sd_`x'03 )^2))
}
restore 

*** Generating matrix of final results

*1. of means
matrix R = (prim_result_all03, itn_result_all03, phone_result_all03, water_result1_all03, water_result2_all03, sani_result1_all03, sani_result2_all03, measles_result_all03, skilled_result_all03, stunted_result_all03, hiv_result_all03\ prim_result_rural03, itn_result_rural03, phone_result_rural03, water_result1_rural03, water_result2_rural03, sani_result1_rural03, sani_result2_rural03, measles_result_rural03, skilled_result_rural03, stunted_result_rural03, hiv_result_rural03\ prim_result_mvregion03, itn_result_mvregion03, phone_result_mvregion03, water_result1_mvregion03, water_result2_mvregion03, sani_result1_mvregion03, sani_result2_mvregion03, measles_result_mvregion03, skilled_result_mvregion03, stunted_result_mvregion03, hiv_result_mvregion03\prim_result_all08, itn_result_all08, phone_result_all08, water_result_all08, water_result_all08, sani_result_all08, sani_result_all08, measles_result_all08, skilled_result_all08, stunted_result_all08, hiv_result_all08\ prim_result_rural08, itn_result_rural08, phone_result_rural08, water_result_rural08, water_result_rural08, sani_result_rural08, sani_result_rural08, measles_result_rural08, skilled_result_rural08, stunted_result_rural08, hiv_result_rural08\ prim_result_mvregion08, itn_result_mvregion08, phone_result_mvregion08, water_result_mvregion08, water_result_mvregion08, sani_result_mvregion08, sani_result_mvregion08, measles_result_mvregion08, skilled_result_mvregion08, stunted_result_mvregion08, hiv_result_mvregion08)
matrix colnames R = prim_result itn_result phone_result water_result1 water_result2  sani_result1 sani_result2 measles_result skilled_result stunted_result hiv_result
matrix rownames R = All2003 Rural2003 Mvregion2003 All2008 Rural2008 Mvregion2008
matlist R

svmat R

* 2. of standard errors
matrix S = (prim_sd_all03, itn_sd_all03, phone_sd_all03, water_sd1_all03, water_sd2_all03, sani_sd1_all03, sani_sd2_all03, measles_sd_all03, skilled_sd_all03, stunted_sd_all03, hiv_sd_all03\prim_sd_rural03, itn_sd_rural03, phone_sd_rural03, water_sd1_rural03, water_sd2_rural03, sani_sd1_rural03, sani_sd2_rural03, measles_sd_rural03, skilled_sd_rural03, stunted_sd_rural03, hiv_sd_rural03\prim_sd_mvregion03, itn_sd_mvregion03, phone_sd_mvregion03, water_sd1_mvregion03, water_sd2_mvregion03, sani_sd1_mvregion03, sani_sd2_mvregion03, measles_sd_mvregion03, skilled_sd_mvregion03, stunted_sd_mvregion03, hiv_sd_mvregion03\prim_sd_all08, itn_sd_all08, phone_sd_all08, water_sd_all08, water_sd_all08, sani_sd_all08, sani_sd_all08, measles_sd_all08, skilled_sd_all08, stunted_sd_all08, hiv_sd_all08\prim_sd_rural08, itn_sd_rural08, phone_sd_rural08, water_sd_rural08, water_sd_rural08, sani_sd_rural08, sani_sd_rural08, measles_sd_rural08, skilled_sd_rural08, stunted_sd_rural08, hiv_sd_rural08\prim_sd_mvregion08, itn_sd_mvregion08, phone_sd_mvregion08, water_sd_mvregion08, water_sd_mvregion08, sani_sd_mvregion08, sani_sd_mvregion08, measles_sd_mvregion08, skilled_sd_mvregion08, stunted_sd_mvregion08, hiv_sd_mvregion08)
matrix colnames S = prim_sd itn_sd phone_sd water_sd1 water_sd2 sani_sd1 sani_sd2 measles_sd skilled_sd stunted_sd hiv_sd
matrix rownames S = All2003 Rural2003 Mvregion2003 All2008 Rural2008 Mvregion2008
matlist S

svmat S

* Generating dataset of final results
rename R1 prim_result
rename R2 itn_result
rename R3 phone_result
rename R4 water_result1
rename R5 water_result2
rename R6 sanitation_result1
rename R7 sanitation_result2
rename R8 measles_result
rename R9 skilled_result
rename R10 stunted_result
rename R11 hiv_result

rename S1 prim_sd
rename S2 itn_sd
rename S3 phone_sd
rename S4 water_sd1
rename S5 water_sd2
rename S6 sanitation_sd1
rename S7 sanitation_sd2
rename S8 measles_sd
rename S9 skilled_sd
rename S10 stunted_sd
rename S11 hiv_sd

* Creating variables for year and coverage. 
input year coverage
2003 1
2003 2
2003 3
2008 1
2008 2
2008 3

tempfile ghana_output ghana_who
save "`ghana_output'"

**** Add in MV data

clear
set obs 2
local vars "year coverage prim_result itn_result phone_result measles_result skilled_result water_result1 water_result2 sanitation_result1 sanitation_result2 stunted_result hiv_result"
foreach x of local vars {
	gen `x' = .
}
replace coverage = 4
replace year = 2006 if _n==1
replace year = 2009 if _n==2

* Add data on Millennium Village
* The following data taken from MVP report "Harvests of Development in Rural Africa: The Millennium Villages After Three Years", p. 87.

replace prim_result = 1.08 if year == 2006
replace itn_result = .09 if year == 2006
replace phone_result = .04 if year == 2006
replace measles_result = .83 if year == 2006
replace skilled_result = .30 if year == 2006
replace water_result1 = .41 if year == 2006
replace water_result2 = .41 if year == 2006
replace sanitation_result1 = .04 if year == 2006
replace sanitation_result2 = .04 if year == 2006
replace stunted_result = .25 if year == 2006
replace hiv_result = 0.04 if year == 2006

replace prim_result = 1.15 if year == 2009
replace itn_result = .56 if year == 2009
replace phone_result = .30 if year == 2009
replace measles_result = .86 if year == 2009
replace skilled_result = .61 if year == 2009
replace water_result1 = .89 if year == 2009
replace water_result2 = .89 if year == 2009
replace sanitation_result1 = .60 if year == 2009
replace sanitation_result2 = .60 if year == 2009
replace stunted_result = .18 if year == 2009
replace hiv_result = 0.13 if year == 2009

label define coveragetypes 1 "Country" 2 "Rural" 3 "MV region, rural" 4 "Millennium Village"
label values coverage coveragetypes

append using "`ghana_output'"
order coverage year
sort coverage year
save "`ghana_output'", replace

* Create tables

set obs 22
g aux = 1
g indicator = sum(aux)
drop aux

* Each observation stands for an indicator or its standard error

foreach k in all03 rural03 mvregion03 all08 rural08 mvregion08 { 
gen `k'=.
}

* Every even observation refers to the indicator, every uneven to its standard error

foreach k in all03 rural03 mvregion03 all08 rural08 mvregion08 { 
capture replace `k'=sani_result1_`k' if indicator==1
capture replace `k'=sani_result2_`k' if indicator==3
capture replace `k'=water_result1_`k' if indicator==5
capture replace `k'=water_result2_`k' if indicator==7
capture replace `k'=measles_result_`k' if indicator==9
capture replace `k'=skilled_result_`k' if indicator==11
capture replace `k'=hiv_result_`k' if indicator==13
capture replace `k'=itn_result_`k' if indicator==15
capture replace `k'=stunted_result_`k' if indicator==17
capture replace `k'=prim_result_`k' if indicator==19
capture replace `k'=phone_result_`k' if indicator==21
capture replace `k'=sani_sd1_`k' if indicator==2
capture replace `k'=sani_sd2_`k' if indicator==4
capture replace `k'=water_sd1_`k' if indicator==6
capture replace `k'=water_sd2_`k' if indicator==8
capture replace `k'=measles_sd_`k' if indicator==10
capture replace `k'=skilled_sd_`k' if indicator==12
capture replace `k'=hiv_sd_`k' if indicator==14
capture replace `k'=itn_sd_`k' if indicator==16
capture replace `k'=stunted_sd_`k' if indicator==18
capture replace `k'=prim_sd_`k' if indicator==20
capture replace `k'=phone_sd_`k' if indicator==22
}

foreach k in all08 rural08 mvregion08 { 
capture replace `k'=sani_result_`k' if indicator==1
capture replace `k'=sani_result_`k' if indicator==3
capture replace `k'=water_result_`k' if indicator==5
capture replace `k'=water_result_`k' if indicator==7
capture replace `k'=sani_sd_`k' if indicator==2
capture replace `k'=sani_sd_`k' if indicator==4
capture replace `k'=water_sd_`k' if indicator==6
capture replace `k'=water_sd_`k' if indicator==8
}

order indicator all03 all08 rural03 rural08 mvregion03 mvregion08

browse

saveold "ghana_table.dta", replace


* Create graphs

graph twoway scatter sanitation_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter sanitation_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter sanitation_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter sanitation_result1 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

graph twoway scatter sanitation_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter sanitation_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter sanitation_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter sanitation_result2 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

graph twoway scatter water_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter water_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter water_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter water_result1 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

graph twoway scatter water_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter water_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter water_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter water_result2 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

graph twoway scatter measles_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter measles_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter measles_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter measles_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Ghana}: Measles vaccination, age < 1", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

graph twoway scatter skilled_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter skilled_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Skilled attendant at birth, age <2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)
		
graph twoway scatter hiv_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter hiv_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Ghana}: HIV testing in last year (15 - 49 year olds)", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

graph twoway scatter itn_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter itn_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter itn_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter itn_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: ITN usage, age < 5", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)
	
graph twoway scatter stunted_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter stunted_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Ghana}: Stunting, age < 2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)

graph twoway scatter prim_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter prim_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter prim_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter prim_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Gross primary attendance ratio", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)
	
graph twoway scatter phone_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(longdash) msize(*1.333) ///
	|| scatter phone_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(shortdash) msize(*1.333) /// 
	|| scatter phone_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter phone_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(black) lcolor(black) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Mobile phone ownership, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(off) scheme(s1color)


/*Create graphs (with legend)
cd "h:\cgd work\migration\millenium villages\ghana mvp analysis"

use "ghana_output.dta"

pause on 

graph twoway scatter sanitation_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter sanitation_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter sanitation_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter sanitation_result1 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter sanitation_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter sanitation_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter sanitation_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter sanitation_result2 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved sanitation, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter water_result1 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter water_result1 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter water_result1 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter water_result1 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter water_result2 year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter water_result2 year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter water_result2 year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter water_result2 year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Improved water source, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter measles_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter measles_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter measles_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter measles_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Ghana}: Measles vaccination, age < 1", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter skilled_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter skilled_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter skilled_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Skilled attendant at birth, age <2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause
		
graph twoway scatter hiv_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter hiv_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter hiv_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Ghana}: HIV testing in last year (15 - 49 year olds)", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter stunted_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter stunted_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter stunted_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.2f)) title("{bf:Ghana}: Stunting, age < 2", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter itn_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter itn_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter itn_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter itn_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: ITN usage, age < 5", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause

graph twoway scatter prim_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter prim_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter prim_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter prim_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Gross primary attendance ratio", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)

pause
	
graph twoway scatter phone_result year if coverage == 1, connect(l) msymbol(O) mcolor(red) lcolor(red) lpattern(dash) msize(*1.333) ///
	|| scatter phone_result year if coverage == 2, connect(l) msymbol(O) mcolor(green) lcolor(green) lpattern(dot) msize(*1.333) /// 
	|| scatter phone_result year if coverage == 3, connect(l) msymbol(O) mcolor(blue) lcolor(blue) msize(*1.333) ///
	|| scatter phone_result year if coverage == 4, connect(l) msymbol(S) mfcolor(white) mlcolor(white) lcolor(white) msize(*1.333) ///
	ylabel( , format(%03.1f)) title("{bf:Ghana}: Mobile phone ownership, households", margin(medium)) ytitle("") xtitle("Year", margin(medium)) ///
	legend(colfirst order(4 1 2 3) cols(2) lab(4 "Millennium Village") lab(1 "Country") lab(2 "Country, rural") lab(3 "MV region, rural") region(lpattern(blank))) scheme(s1rcolor)
*/
	
	
	
	
